# Generated by roxygen2: do not edit by hand

S3method(print,orbit_system)
export(add_body)
export(add_body_keplerian)
export(add_planet)
export(add_sun)
export(animate_system)
export(animate_system_3d)
export(create_system)
export(distance_earth_moon)
export(distance_earth_sun)
export(distance_jupiter_sun)
export(distance_mars_sun)
export(distance_mercury_sun)
export(distance_neptune_sun)
export(distance_pluto_sun)
export(distance_saturn_sun)
export(distance_uranus_sun)
export(distance_venus_sun)
export(export_bodies)
export(get_bodies)
export(gravitational_constant)
export(load_solar_system)
export(load_system)
export(mass_earth)
export(mass_jupiter)
export(mass_mars)
export(mass_mercury)
export(mass_moon)
export(mass_neptune)
export(mass_pluto)
export(mass_saturn)
export(mass_sun)
export(mass_uranus)
export(mass_venus)
export(plot_orbits)
export(plot_orbits_3d)
export(plot_system)
export(plot_system_3d)
export(remove_body)
export(save_system)
export(seconds_per_day)
export(seconds_per_hour)
export(seconds_per_year)
export(shift_reference_frame)
export(simulate_system)
export(speed_earth)
export(speed_jupiter)
export(speed_mars)
export(speed_mercury)
export(speed_moon)
export(speed_neptune)
export(speed_pluto)
export(speed_saturn)
export(speed_uranus)
export(speed_venus)
importFrom(Rcpp,sourceCpp)
useDynLib(orbitr, .registration = TRUE)
